Discover Packages
github.com/Astemirdum/transactions
tx-balance
config
package
Version:
v0.0.0-...-5122af3
Opens a new window with list of versions in this module.
Published: Nov 20, 2022
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Config struct {
Server Server `yaml:"server"`
Database DB `yaml:"db"`
JS JS `yaml:"js"`
AuthClient AuthClient `yaml:"authClient"`
InitCash int
}
type DB struct {
Host string `yaml:"host"`
Port int `yaml:"port"`
Username string `yaml:"user"`
Password string `yaml:"password"`
NameDB string `yaml:"dbname"`
}
type JS struct {
URL string `yaml:"url"`
MaxReconnects int `yaml:"maxReconnects"`
ReconnectWait time .Duration `yaml:"reconnectWait"`
ConnectTimeout time .Duration `yaml:"connectTimeout"`
WorkerCount int `yaml:"workerCount"`
}
type Server struct {
Host string `yaml:"host"`
Port string `yaml:"port"`
ReadTimeout time .Duration `yaml:"readTimeout"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.