package
Version:
v0.0.0-...-5122af3
Opens a new window with list of versions in this module.
Published: Nov 20, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Balance struct {
ID int `db:"id"`
UserID int `db:"user_id"`
Cash uint64 `db:"cash"`
LastTransaction int64 `db:"last_transaction"`
}
type CashOut struct {
UserID int
Cash uint64
}
type CashOutMsg struct {
Cash uint64 `json:"cash"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.