Documentation
¶
Index ¶
- Constants
- func NewBalanceServiceHandler(svc BalanceServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
- type BalanceServiceClient
- type BalanceServiceHandler
- type UnimplementedBalanceServiceHandler
- func (UnimplementedBalanceServiceHandler) CashOut(context.Context, *connect_go.Request[v1.CashOutRequest]) (*connect_go.Response[v1.CashOutResponse], error)
- func (UnimplementedBalanceServiceHandler) CreateBalance(context.Context, *connect_go.Request[v1.CreateBalanceRequest]) (*connect_go.Response[v1.CreateBalanceResponse], error)
- func (UnimplementedBalanceServiceHandler) GetBalance(context.Context, *connect_go.Request[v1.GetBalanceRequest]) (*connect_go.Response[v1.GetBalanceResponse], error)
Constants ¶
const (
// BalanceServiceName is the fully-qualified name of the BalanceService service.
BalanceServiceName = "balance.v1.BalanceService"
)
Variables ¶
This section is empty.
Functions ¶
func NewBalanceServiceHandler ¶
func NewBalanceServiceHandler(svc BalanceServiceHandler, opts ...connect_go.HandlerOption) (string, http.Handler)
NewBalanceServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type BalanceServiceClient ¶
type BalanceServiceClient interface {
CreateBalance(context.Context, *connect_go.Request[v1.CreateBalanceRequest]) (*connect_go.Response[v1.CreateBalanceResponse], error)
GetBalance(context.Context, *connect_go.Request[v1.GetBalanceRequest]) (*connect_go.Response[v1.GetBalanceResponse], error)
CashOut(context.Context, *connect_go.Request[v1.CashOutRequest]) (*connect_go.Response[v1.CashOutResponse], error)
}
BalanceServiceClient is a client for the balance.v1.BalanceService service.
func NewBalanceServiceClient ¶
func NewBalanceServiceClient(httpClient connect_go.HTTPClient, baseURL string, opts ...connect_go.ClientOption) BalanceServiceClient
NewBalanceServiceClient constructs a client for the balance.v1.BalanceService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type BalanceServiceHandler ¶
type BalanceServiceHandler interface {
CreateBalance(context.Context, *connect_go.Request[v1.CreateBalanceRequest]) (*connect_go.Response[v1.CreateBalanceResponse], error)
GetBalance(context.Context, *connect_go.Request[v1.GetBalanceRequest]) (*connect_go.Response[v1.GetBalanceResponse], error)
CashOut(context.Context, *connect_go.Request[v1.CashOutRequest]) (*connect_go.Response[v1.CashOutResponse], error)
}
BalanceServiceHandler is an implementation of the balance.v1.BalanceService service.
type UnimplementedBalanceServiceHandler ¶
type UnimplementedBalanceServiceHandler struct{}
UnimplementedBalanceServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedBalanceServiceHandler) CashOut ¶
func (UnimplementedBalanceServiceHandler) CashOut(context.Context, *connect_go.Request[v1.CashOutRequest]) (*connect_go.Response[v1.CashOutResponse], error)
func (UnimplementedBalanceServiceHandler) CreateBalance ¶
func (UnimplementedBalanceServiceHandler) CreateBalance(context.Context, *connect_go.Request[v1.CreateBalanceRequest]) (*connect_go.Response[v1.CreateBalanceResponse], error)
func (UnimplementedBalanceServiceHandler) GetBalance ¶
func (UnimplementedBalanceServiceHandler) GetBalance(context.Context, *connect_go.Request[v1.GetBalanceRequest]) (*connect_go.Response[v1.GetBalanceResponse], error)